@@ -752,7 +752,6 @@ def get_confusion_matrix(input_tfrecord_path, model, labelmap, iou_thresh=0.5, c
                 detection_classes   = detections['detection_classes'][0].numpy()[detection_scores >= CONFIDENCE_THRESHOLD].astype('uint8')
                 filename            = decoded_dict[fields.InputDataFields.filename]
                 filename            = filename.decode('UTF-8') if filename is not None else f'image-{image_index}.png'
-                print(filename)
                 matches = []
                 image_index += 1
                 gt_boxes = []
@@ -779,9 +778,6 @@ def get_confusion_matrix(input_tfrecord_path, model, labelmap, iou_thresh=0.5, c
                     
                     # Remove duplicate ground truths from the list.
                     matches = matches[np.unique(matches[:,0], return_index=True)[1]]
-                print(matches)
-                print(groundtruth_classes)
-                print(detection_classes)
                 nb_objects = np.zeros(len(categories))
                 nb_preds = np.zeros(len(categories))
                 FN = np.zeros(len(categories))
